@@ -21,6 +21,7 @@
 
 """Collection of Slovenian numbers."""
 
-# provide vat as an alias
+# provide aliases
 from stdnum.si import ddv as vat  # noqa: F401
 from stdnum.si import emso as personalid  # noqa: F401
+from stdnum.si import maticna as businessid  # noqa: F401
