@@ -28,7 +28,7 @@ More information:
 
 * https://en.wikipedia.org/wiki/National_identification_number#Netherlands
 * https://nl.wikipedia.org/wiki/Burgerservicenummer
-* http://www.burgerservicenummer.nl/
+* https://www.burgerservicenummer.nl/
 
 >>> validate('1112.22.333')
 '111222333'
@@ -45,15 +45,13 @@ InvalidLength: ...
 """
 
 from stdnum.exceptions import *
-from stdnum.util import clean
+from stdnum.util import clean, isdigits
 
 
 def compact(number):
     """Convert the number to the minimal representation. This strips the
     number of any valid separators and removes surrounding whitespace."""
-    number = clean(number, ' -.').strip()
-    # pad with leading zeroes
-    return (9 - len(number)) * '0' + number
+    return clean(number, ' -.').strip().zfill(9)
 
 
 def checksum(number):
@@ -67,7 +65,7 @@ def validate(number):
     """Check if the number is a valid BSN. This checks the length and whether
     the check digit is correct."""
     number = compact(number)
-    if not number.isdigit() or int(number) <= 0:
+    if not isdigits(number) or int(number) <= 0:
         raise InvalidFormat()
     if len(number) != 9:
         raise InvalidLength()
